*******************************************
** REPLICATION FILES FOR
** Dynes, Adam M., and Gregory A. Huber. 2015. "Partisanship and the Allocation of Federal Spending: Do Same-Party Legislators or Voters Benefit from Shared Party Affiliation with the President and House Majority?" American Political Science Review 109 (1):
** 
** SCRIPT 3-2: Analysis of Data -- Create Tables and Figures in Paper and Appendix
*******************************************

clear all
set more off
set matsize 800

use dynes-huber_2015_partisanship_replication_final-dataset.dta

*Drop capital districts
	drop if capital==1
	local samplerestriction="Excludes cases: Dropped by BBH, "
	local samplerestriction="`samplerestriction' Multiple occupants of seat, "	
	local samplerestriction="`samplerestriction' State capitals, "

*Declare panel data
	xtset fe_districtcensus fyear

*Set common sample
	qui xtreg logoutlays memberinpresparty memberinhouseparty chair rankingminority partyleader cmte_approp cmte_ways memberisrep firstterm closeelection votemargin_pres_state yeardummy_*, cluster(state)
	gen useme=e(sample)

	tab fyear if e(sample)

*********
*Figure 1
*********

preserve

*Keep specific observations
	drop if fe_districtcensusmemberhouse==.

	*Years in which presidency switches and we have data on both sides of switch
		keep if eyear==1998 | eyear==2000 | eyear==2006 | eyear==2008
	*and single spending years on both sides of change for consistency
	*NOTE THAT COLLAPSE BELOW USES MAX, SO IF YOU USE MORE THAN ONE YEAR ON EITHER SIDE, YOU NEED TAKE MEANS ON EACH SIDE AND THEN MAX WILL BE OK
		keep if fyear==2001 | fyear==2002 | fyear==2009 | fyear==2010

	*get rid of capitals
		drop if capital==1
	
*Set panel data
	xtset fe_districtcensusmemberhouse fyear

*Need to see same person on both sides of switch
	bysort fe_districtcensusmemberhouse: egen minpresisrep=min(presisrep)
	bysort fe_districtcensusmemberhouse: egen maxpresisrep=max(presisrep)
	drop if minpresisrep==maxpresisrep

	collapse (mean) logoutlays logalloutlays districtpartisanship presisrep memberisrep, by(fe_districtcensusmemberhouse eyear)
	gen comparison=1
	replace comparison=0 if eyear==1998 | eyear==2000
	sort fe_districtcensusmemberhouse eyear

*Make sure no difference in party id measures for these cases
	drop if (districtpartisanship~=districtpartisanship[_n-1] & fe_districtcensusmemberhouse==fe_districtcensusmemberhouse[_n-1]) | (districtpartisanship~=districtpartisanship[_n+1] & fe_districtcensusmemberhouse==fe_districtcensusmemberhouse[_n+1])

	gen pre_logoutlays = logoutlays*(eyear==1998 | eyear==2006)
	gen post_logoutlays = logoutlays*(eyear==2000 | eyear==2008)
	gen pre_logalloutlays = logalloutlays*(eyear==1998 | eyear==2006)
	gen post_logalloutlays = logalloutlays*(eyear==2000 | eyear==2008)

	collapse (max) pre_logoutlays post_logoutlays  pre_logalloutlays post_logalloutlays (mean)  memberisrep districtpartisanship, by(comparison fe_districtcensusmemberhouse)
	gen delta_logoutlays=(post_logoutlays-pre_logoutlays)
	gen delta_logalloutlays=(post_logalloutlays-pre_logalloutlays)
	drop if delta_logoutlays==. | delta_logalloutlays==.

*Top and bottom code delta spending measures for readability. These are not the figures used to calculate the lowess, just for the graph to make it easier to read.
	gen delta_logoutlaystc=delta_logoutlays
	gen delta_logalloutlaystc=delta_logalloutlays

	replace delta_logoutlaystc=.5 if delta_logoutlays>.5
	replace delta_logoutlaystc=-.5 if delta_logoutlays<-.5
	replace delta_logalloutlaystc=.2 if delta_logalloutlays>.2
	replace delta_logalloutlaystc=-.2 if delta_logalloutlays<-.2

	label var districtpartisanship "District Republican Tendency"

	gen pidofmember="D"
	replace pidofmember="R" if memberisrep==1

	save temp.dta, replace

*First do Clinton to Bush II transition
	keep if comparison == 0
	set scheme s1mono
	
*Change in High Variance Spending from from Clinton to Bush II
	#delimit ;
	twoway
	(scatter delta_logoutlaystc districtpartisanship if memberisrep==1,mcolor(none) msize(zero) mlabel(pidofmember) mlabsize(small) mlabcolor(black) mlabposition(0) ytitle("Change in Log of High Variance Spending", size(small)) xtitle("District Republican Tendency"))
	(scatter delta_logoutlaystc districtpartisanship if memberisrep==0, mcolor(none) msize(zero) mlabel(pidofmember) mlabsize(small) mlabcolor(gray) mlabposition(0))
	(lowess delta_logoutlays districtpartisanship if memberisrep==1, lpattern(solid))
	(lowess delta_logoutlays districtpartisanship if memberisrep==0,lpattern(dot))
	,
	legend(off)
	title("Panel A")
	subtitle("Change in High Variance Spending in House Districts from Clinton to Bush II, by Member Partisanship" "Includes observations for House members elected in both 1998 and 2000 who don't change parties", size(small))
	name(clintonbush_highvar_all, replace);
	#delimit cr

*Change in All Spending from from Clinton to Bush II
	#delimit ;
	twoway
	(scatter delta_logalloutlaystc districtpartisanship if memberisrep==1,mcolor(none) msize(zero) mlabel(pidofmember) mlabsize(small) mlabcolor(black) mlabposition(0) ytitle("Change in Log of All Spending", size(small)) xtitle("District Republican Tendency"))
	(scatter delta_logalloutlaystc districtpartisanship if memberisrep==0, mcolor(none) msize(zero) mlabel(pidofmember) mlabsize(small) mlabcolor(gray) mlabposition(0))
	(lowess delta_logalloutlays districtpartisanship if memberisrep==1, lpattern(solid))
	(lowess delta_logalloutlays districtpartisanship if memberisrep==0,lpattern(dot))
	,
	legend(off)
	title("Panel B")
	subtitle("Change in All Spending in House Districts from Clinton to Bush II, by Member Partisanship" "Includes observations for House members elected in both 1998 and 2000 who don't change parties", size(small))
	legend(order( 3 "Republican controlled seats" 4 "Democrat controlled seats"))
	name(clintonbush_all_all, replace);
	#delimit cr

*Next do Bush II to Obama  transition
	clear
	use temp.dta
	!erase temp.dta, replace
	keep if comparison == 1

*Change in High Variance Spending from Bush II to Obama
	#delimit ;
	twoway
	(scatter delta_logoutlaystc districtpartisanship if memberisrep==1,mcolor(none) msize(zero) mlabel(pidofmember) mlabsize(small) mlabcolor(black) mlabposition(0) ytitle("Change in Log of High Variance Spending", size(small)) xtitle("District Republican Tendency"))
	(scatter delta_logoutlaystc districtpartisanship if memberisrep==0, mcolor(none) msize(zero) mlabel(pidofmember) mlabsize(small) mlabcolor(gray) mlabposition(0))
	(lowess delta_logoutlays districtpartisanship if memberisrep==1, lpattern(solid))
	(lowess delta_logoutlays districtpartisanship if memberisrep==0,lpattern(dot))
	,
	legend(off)
	title("Panel C")
	subtitle("hange in High Variance Spending in House Districts from Bush II to Obama, by Member Partisanship" "Includes observations for House members elected in both 2006 and 2008 who don't change parties", size(small))
	name(bushobama_highvar_all, replace);
	#delimit cr
	

*Change in All Spending from Bush II to Obama	
	#delimit ;
	twoway
	(scatter delta_logalloutlaystc districtpartisanship if memberisrep==1,mcolor(none) msize(zero) mlabel(pidofmember) mlabsize(small) mlabcolor(black) mlabposition(0) ytitle("Change in Log of All Spending", size(small)) xtitle("District Republican Tendency"))
	(scatter delta_logalloutlaystc districtpartisanship if memberisrep==0, mcolor(none) msize(zero) mlabel(pidofmember) mlabsize(small) mlabcolor(gray) mlabposition(0))
	(lowess delta_logalloutlays districtpartisanship if memberisrep==1, lpattern(solid))
	(lowess delta_logalloutlays districtpartisanship if memberisrep==0,lpattern(dot))
	,
	legend(off)
	title("Panel D")
	subtitle("Change in All Spending in House Districts from Bush II to Obama, by Member Partisanship" "Includes observations for House members elected in both 2006 and 2008 who don't change parties", size(small))
	name(bushobama_all_all, replace);
	#delimit cr
	
*Generate Figure 1
	graph combine clintonbush_highvar_all clintonbush_all_all bushobama_highvar_all bushobama_all_all, xcommon rows(2) scheme(s1mono) xsize(10) ysize(7.5) scale(.6) title("Figure 1: Change in Spending Associated with Change in Party Control of Presidency" "By District Republican Tendency and Member Partisanship", size(medium))

restore


****
*table 1
****

*High variance spending first

	local outregtable "table1"
	xtset fe_districtcensus fyear
	local clabel="District + Census Fixed Effects"

preserve

	keep if useme==1 & fyear<=2007
	local yearstring "2007 and before"
	local cslcol=""
	local note : variable label logoutlays

	quietly  xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	keep if e(sample)
 
	qui summ logoutlays if e(sample)
	local outcomemean=r(mean)
 
	xtreg logoutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addnote("Dependent variable is `note'. `samplerestriction'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) replace	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addnote("Dependent variable is `note'. `samplerestriction'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster replace
  
	xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
  
restore

preserve

	keep if useme==1
	local yearstring "All years"
	local cslcol=""

	quietly xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	keep if e(sample)
   
	qui summ logoutlays if e(sample)
	local outcomemean=r(mean)
  
	xtreg logoutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
  
	xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
     
restore
 
*Low variance spending next

	local outregtable "table1"
	xtset fe_districtcensus fyear
	local clabel="District + Census Fixed Effects"

preserve

	keep if useme==1
	local yearstring "All years"
	local cslcol=""
 
	quietly xtreg logalloutlays memberinpresparty memberinhouseparty chair rankingminority partyleader cmte_approp cmte_ways memberisrep closeelection presparty_close housmaj_close firstterm votemargin_pres_state presrep_distrepubtend houserep_distrepubtend yeardummy_*, fe vce(robust)
	keep if e(sample)

	qui summ logalloutlays if e(sample)
	local outcomemean=r(mean)
 
	xtreg logalloutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
 
	xtreg logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append

restore

***
*table A10: districts with common support for both parties
***

	*NOTE: This analysis is in the robustness section. It is the calculation of district overlap--what range of district preferences generates both Democratic and Republican House members and do we continue to see effects in this subsample?

preserve
 
	keep if useme==1
	local yearstring "All years"
	local cslcol=""
 
*set sample
	qui xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
 
	bysort eyear: egen temp=min(districtpartisanship) if memberisrep==1 & e(sample)
	bysort eyear: egen mostlibrepplace=mean(temp) if e(sample)
	drop temp
 
	bysort eyear: egen temp=max(districtpartisanship) if memberisrep==0 & e(sample)
	bysort eyear: egen mostcondemplace=mean(temp) if e(sample)
	drop temp
 
	gen overlap=districtpartisanship>=mostlibrepplace & districtpartisanship<=mostcondemplace
	gen r= mostcondemplace- mostlibrepplace
	table eyear if e(sample), c(mean overlap mean r) 

	gen z=int(eyear/10)
	table z if e(sample), c(mean overlap mean r) 
 
*Regressions
	xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_* if overlap, fe vce(robust)
	qui summ logoutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "tableA10_common-support.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) replace	
		*outreg using "tableA10_common-support.out", ctitle("`clabel', `yearstring'`cslcol'")asterisk(se)bracket bdec(3) tdec(3) 3aster replace
		
	xtreg logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_* if overlap, fe vce(robust)
	qui summ logalloutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "tableA10_common-support.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) append	
		*outreg using "tableA10_common-support.out", ctitle("`clabel', `yearstring'`cslcol'")asterisk(se)bracket bdec(3) tdec(3) 3aster append

restore
  
 
****
*table 2, Part A, Which districts benefits when nothing changes except control of the house?
****

preserve

	xtset fe_districtcensusmemberpres fyear

	bysort fe_districtcensusmemberpres: egen minhouseisrep=min(houseisrep)
	bysort fe_districtcensusmemberpres: egen maxhouseisrep=max(houseisrep)
	count if minhouseisrep~=maxhouseisrep
		*These are people who experience a change
	drop if minhouseisrep==maxhouseisrep

	tab eyear houseisrep

*generate time dummies
	drop yeardummy_*
	qui tab fyear, gen(yeardummy_)
	drop yeardummy_1

*set sample
	qui xtreg logoutlays logalloutlays presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm  yeardummy_*, fe vce(robust)
	drop if e(sample)~=1

*Regressions	
	foreach dv of varlist logoutlays logalloutlays {

		if "`dv'"=="logoutlays" {
			local dvlabel="H. Var. Outlays"
		}
		else if "`dv'"=="logalloutlays" {
			local dvlabel="All Outlays"
		} 
		else {
			Crashing!
		}

		xtreg `dv' presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm  yeardummy_*, fe vce(robust)
		qui summ `dv' if e(sample)
		local outcomemean=r(mean)
	 
		if "`dv'"=="logoutlays" {
			 outreg2 using "table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) replace		
			 *outreg using "table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster replace
		}
		else {
			 outreg2 using "table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append		
			 *outreg using "table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
		}
 
	}
 
	bysort eyear: egen temp=min(districtpartisanship) if memberisrep==1 & e(sample)
	bysort eyear: egen mostlibrepplace=mean(temp) if e(sample)
	drop temp
 
	bysort eyear: egen temp=max(districtpartisanship) if memberisrep==0 & e(sample)
	bysort eyear: egen mostcondemplace=mean(temp) if e(sample)
	drop temp
 
	gen overlap=districtpartisanship>=mostlibrepplace & districtpartisanship<=mostcondemplace

	foreach dv of varlist logoutlays logalloutlays {

		if "`dv'"=="logoutlays" {
			local dvlabel="H. Var. Outlays"
		}
		else if "`dv'"=="logalloutlays" {
			local dvlabel="All Outlays"
		} 
		else {
			Crashing!
		}
 
		qui summ `dv' if e(sample)
		local outcomemean=r(mean)
 
		xtreg `dv' presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm  yeardummy_* if overlap==1, fe vce(robust)
			outreg2 using "tableA10_common-support.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append		
			*outreg using "tableA10_common-support.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
 
	} 
 
restore

****
*table 2, part B. Which districts benefits when nothing changes except control of the presidency?
****

preserve

	xtset fe_districtcensusmemberhouse fyear

	bysort fe_districtcensusmemberhouse: egen minpresisrep=min(presisrep)
	bysort fe_districtcensusmemberhouse: egen maxpresisrep=max(presisrep)
	count if minpresisrep~=maxpresisrep
		*These are people who experience a change
	drop if minpresisrep==maxpresisrep

	tab eyear presisrep

*generate time dummies
	drop yeardummy_*
	qui tab fyear, gen(yeardummy_)
	drop yeardummy_1

*set sample
	qui xtreg  logoutlays logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm yeardummy_*, fe vce(robust)
	drop if e(sample)~=1
 
	foreach dv of varlist logoutlays logalloutlays {

		if "`dv'"=="logoutlays" {
			local dvlabel="H. Var. Outlays"
		}
		else if "`dv'"=="logalloutlays" {
			local dvlabel="All Outlays"
		} 
		else {
			Crashing!
		}
 
		xtreg `dv' memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm yeardummy_*, fe vce(robust)
	   
		qui summ `dv' if e(sample)
		local outcomemean=r(mean)
		
			outreg2 using "table2.out", ctitle("`dvlabel', Holding House Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	 
			*outreg using "table2.out", ctitle("`dvlabel', Holding House Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
 
	}

	bysort eyear: egen temp=min(districtpartisanship) if memberisrep==1 & e(sample)
	bysort eyear: egen mostlibrepplace=mean(temp) if e(sample)
	drop temp
 
	bysort eyear: egen temp=max(districtpartisanship) if memberisrep==0 & e(sample)
	bysort eyear: egen mostcondemplace=mean(temp) if e(sample)
	drop temp
 
	gen overlap=districtpartisanship>=mostlibrepplace & districtpartisanship<=mostcondemplace

	foreach dv of varlist logoutlays logalloutlays {

		if "`dv'"=="logoutlays" {
			local dvlabel="H. Var. Outlays"
		}
		else if "`dv'"=="logalloutlays" {
			local dvlabel="All Outlays"
		} 
		else {
			Crashing!
		}
 
		xtreg `dv' memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm yeardummy_*  if overlap==1, fe vce(robust)
   
		qui summ `dv' if e(sample)
		local outcomemean=r(mean)

			outreg2 using "tableA10_common-support.out", ctitle("`dvlabel', Holding House Party and Member Constant") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append
			*outreg using "tableA10_common-support.out", ctitle("`dvlabel', Holding House Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	}

restore




****
*table A8: table 1 with Alternative Measures of District Republican Tendency
****

*High variance spending first

	local outregtable "tableA8_alt-DRT"
	xtset fe_districtcensus fyear
	local clabel="District + Census Fixed Effects"

preserve

	keep if useme==1
	local yearstring "All years"
	local cslcol=""
	
	qui xtreg logoutlays logalloutlays memberinpresparty presrep_distrepubtend2 presrep_distrepubtend3 presrep_distrepubtend4 presrep_distrepubtend5 presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend2 houserep_distrepubtend3 houserep_distrepubtend4 houserep_distrepubtend5 housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	keep if e(sample)

	foreach number in 2 3 4 5 {
	local cslcol="Alt. Dist. Rep. Tend. `number'"
	
	xtreg logoutlays memberinpresparty presrep_distrepubtend`number' presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend`number' housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	qui summ logoutlays if e(sample)
	local outcomemean=r(mean)	

	if "`number'"=="2" {	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring', `cslcol', High Var. Spending") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) replace	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster replace
	}
	
	else {
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring', `cslcol', High Var. Spending") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	}
	}
	
restore
 
*Low variance spending next

	local outregtable "tableA8_alt-DRT"
	xtset fe_districtcensus fyear
	local clabel="District + Census Fixed Effects"

preserve

	keep if useme==1
	local yearstring "All years"
	local cslcol=""

	qui xtreg logoutlays logalloutlays memberinpresparty presrep_distrepubtend2 presrep_distrepubtend3 presrep_distrepubtend4 presrep_distrepubtend5 presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend2 houserep_distrepubtend3 houserep_distrepubtend4 houserep_distrepubtend5 housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	keep if e(sample)	

	foreach number in 2 3 4 5 {
	local cslcol="Alt. Dist. Rep. Tend. `number'"
	
	xtreg logalloutlays memberinpresparty presrep_distrepubtend`number' presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend`number' housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	qui summ logalloutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring', `cslcol', All Spending") addstat("Mean of outcome in sample",`outcomemean') asterisk(se) bracket adec(3) bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	}
	
restore



****
*table A11: table 1 with Senate-related variables
****

*High variance spending first

	local outregtable "tableA11_senate"
	xtset fe_districtcensus fyear
	local clabel="District + Census Fixed Effects"

preserve

	keep if useme==1 & fyear<=2007
	local yearstring "2007 and before"
	local cslcol=""
	local note : variable label logoutlays

	qui xtreg logoutlays senatorsinpresparty senatorsinsenmajority senaterep_distrepubtend republicansenators memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)	
	keep if e(sample)
		
	xtreg logoutlays senatorsinpresparty senatorsinsenmajority memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
	qui summ logoutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean') addnote("Dependent variable is `note'. `samplerestriction'")asterisk(se)bracket bdec(3) tdec(3) replace	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean') addnote("Dependent variable is `note'. `samplerestriction'")asterisk(se)bracket bdec(3) tdec(3) 3aster replace
  
	xtreg logoutlays senatorsinpresparty senatorsinsenmajority senaterep_distrepubtend republicansenators memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	qui summ logoutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) 3aster append
  
restore

preserve

	keep if useme==1
	local yearstring "All years"
	local cslcol=""
	
	qui xtreg logoutlays senatorsinpresparty senatorsinsenmajority senaterep_distrepubtend republicansenators memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)	
	keep if e(sample)	

	xtreg logoutlays senatorsinpresparty senatorsinsenmajority memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
	qui summ logoutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) 3aster append
  
	xtreg logoutlays senatorsinpresparty senatorsinsenmajority senaterep_distrepubtend republicansenators memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	qui summ logoutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) 3aster append
  
restore
 
*Low variance spending next

	local outregtable "tableA11_senate"
	xtset fe_districtcensus fyear
	local clabel="District + Census Fixed Effects"

preserve

	qui xtreg logoutlays senatorsinpresparty senatorsinsenmajority senaterep_distrepubtend republicansenators memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)	
	keep if e(sample)

	keep if useme==1
	local yearstring "All years"
	local cslcol=""

	xtreg logalloutlays senatorsinpresparty senatorsinsenmajority memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
	qui summ logalloutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) 3aster append
 
	xtreg logalloutlays senatorsinpresparty senatorsinsenmajority senaterep_distrepubtend republicansenators memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	qui summ logalloutlays if e(sample)
	local outcomemean=r(mean)	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket bdec(3) tdec(3) 3aster append

restore

****
*table A13: table 1 with Alternative Coefficients of Variation
****

*High variance spending first

	local outregtable "tableA13_alt-coeff-var"
	xtset fe_districtcensus fyear
	local clabel="District + Census Fixed Effects"

preserve

	keep if useme==1
	local yearstring "All years"
	local cslcol=""
	
	gen logoutlays100 = logoutlays
	
	qui xtreg logoutlays33 logoutlays66 logoutlays100 logoutlays133 logoutlays166 logoutlays200 logoutlays300 memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	keep if e(sample)

	foreach number in 33 66 100 133 166 200 300 {
	local threshold = `number'/100
	local cslcol="Coeff. of Var.>`threshold'"
	
	xtreg logoutlays`number' memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
	qui summ logoutlays`number' if e(sample)
	local outcomemean=r(mean)	

	if "`number'"=="33" {	
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring', `cslcol', High Var. Spending") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) replace	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster replace
	}
	
	else {
		outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring', `cslcol', High Var. Spending") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
		*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	}
	}
	
restore



****
*table A9: table 1 & 2, Even Years Only
****

*table 1, Even Years Only

	*KEEP only even years
		keep if int(fyear/2)==(fyear/2)
		local samplerestriction="`samplerestriction' Odd years, "	
	
	*Declare panel data
		xtset fe_districtcensus fyear

	*Set common sample
		qui xtreg logoutlays memberinpresparty memberinhouseparty chair rankingminority partyleader cmte_approp cmte_ways memberisrep firstterm closeelection votemargin_pres_state yeardummy_*, cluster(state)
		tab fyear if e(sample)


	*High variance spending first

		local outregtable "tableA9_even-years_table1"
		xtset fe_districtcensus fyear
		local clabel="District + Census Fixed Effects"

	preserve

		keep if useme==1 & fyear<=2007
		local yearstring "2007 and before"
		local cslcol=""
		local note : variable label logoutlays

		quietly  xtreg logoutlays logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
		keep if e(sample)
	 
		qui summ logoutlays if e(sample)
		local outcomemean=r(mean)
	 
		xtreg logoutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addnote("Dependent variable is `note'. `samplerestriction'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) replace	
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addnote("Dependent variable is `note'. `samplerestriction'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster replace
	  
		xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	  
	restore

	preserve

		keep if useme==1
		local yearstring "All years"
		local cslcol=""

		quietly xtreg logoutlays logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
		keep if e(sample)
	   
		qui summ logoutlays if e(sample)
		local outcomemean=r(mean)
	  
		xtreg logoutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	  
		xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
		 
	restore
	 
	*Low variance spending next

		local outregtable "tableA9_even-years_table1"
		xtset fe_districtcensus fyear
		local clabel="District + Census Fixed Effects"

	preserve

		keep if useme==1
		local yearstring "All years"
		local cslcol=""
	 
		quietly xtreg logoutlays logalloutlays memberinpresparty memberinhouseparty chair rankingminority partyleader cmte_approp cmte_ways memberisrep closeelection presparty_close housmaj_close firstterm votemargin_pres_state presrep_distrepubtend houserep_distrepubtend yeardummy_*, fe vce(robust)
		keep if e(sample)

		qui summ logalloutlays if e(sample)
		local outcomemean=r(mean)
	 
		xtreg logalloutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	 
		xtreg logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append

	restore


*table 2, Part A, Even Years Only

	preserve

		xtset fe_districtcensusmemberpres fyear

		bysort fe_districtcensusmemberpres: egen minhouseisrep=min(houseisrep)
		bysort fe_districtcensusmemberpres: egen maxhouseisrep=max(houseisrep)
		count if minhouseisrep~=maxhouseisrep
			*These are people who experience a change
		drop if minhouseisrep==maxhouseisrep

		tab eyear houseisrep

	*generate time dummies
		drop yeardummy_*
		qui tab fyear, gen(yeardummy_)
		drop yeardummy_1

	*set sample
		qui xtreg  logoutlays logalloutlays presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm  yeardummy_*, fe vce(robust)
		drop if e(sample)~=1

	*Regressions	
		foreach dv of varlist logoutlays logalloutlays {

			if "`dv'"=="logoutlays" {
				local dvlabel="H. Var. Outlays"
			}
			else if "`dv'"=="logalloutlays" {
				local dvlabel="All Outlays"
			} 
			else {
				Crashing!
			}

			xtreg `dv' presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm  yeardummy_*, fe vce(robust)
			qui summ `dv' if e(sample)
			local outcomemean=r(mean)
		 
			if "`dv'"=="logoutlays" {
				 outreg2 using "tableA9_even-years_table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) replace		
				 *outreg using "tableA9_even-years_table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster replace
			}
			else {
				 outreg2 using "tableA9_even-years_table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append		
				 *outreg using "tableA9_even-years_table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
			}
	 
		}
	 
	 
	restore


*table 2, part B, Even Years Only

	preserve

		xtset fe_districtcensusmemberhouse fyear

		bysort fe_districtcensusmemberhouse: egen minpresisrep=min(presisrep)
		bysort fe_districtcensusmemberhouse: egen maxpresisrep=max(presisrep)
		count if minpresisrep~=maxpresisrep
			*These are people who experience a change
		drop if minpresisrep==maxpresisrep

		tab eyear presisrep

	*generate time dummies
		drop yeardummy_*
		qui tab fyear, gen(yeardummy_)
		drop yeardummy_1

	*set sample
		qui xtreg logoutlays logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm yeardummy_*, fe vce(robust)
		drop if e(sample)~=1

	*regressions
		foreach dv of varlist logoutlays logalloutlays {

			if "`dv'"=="logoutlays" {
				local dvlabel="H. Var. Outlays"
			}
			else if "`dv'"=="logalloutlays" {
				local dvlabel="All Outlays"
			} 
			else {
				Crashing!
			}
	 
			xtreg `dv' memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm yeardummy_*, fe vce(robust)
		   
			qui summ `dv' if e(sample)
			local outcomemean=r(mean)
			
				outreg2 using "tableA9_even-years_table2.out", ctitle("`dvlabel', Holding House Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	 
				*outreg using "tableA9_even-years_table2.out", ctitle("`dvlabel', Holding House Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	 
		}

	restore




****
*table A12: table 1 & 2 with State Capital Districts
****

*table 1 with State Capital Districts
	clear all
	set more off
	set matsize 800

	use dynes-huber_2015_partisanship_replication_final-dataset.dta


	*Declare panel data
		xtset fe_districtcensus fyear

	*Set common sample
		qui xtreg logoutlays memberinpresparty memberinhouseparty chair rankingminority partyleader cmte_approp cmte_ways memberisrep firstterm closeelection votemargin_pres_state yeardummy_*, cluster(state)
		gen useme=e(sample)

		tab fyear if e(sample)


	*High variance spending first

		local outregtable "tableA12_capitals_table1"
		xtset fe_districtcensus fyear
		local clabel="District + Census Fixed Effects"

	preserve

		keep if useme==1 & fyear<=2007
		local yearstring "2007 and before"
		local cslcol=""
		local note : variable label logoutlays

		quietly  xtreg logoutlays logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
		keep if e(sample)
	 
		qui summ logoutlays if e(sample)
		local outcomemean=r(mean)
	 
		xtreg logoutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addnote("Dependent variable is `note'. `samplerestriction'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) replace	
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addnote("Dependent variable is `note'. `samplerestriction'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster replace
	  
		xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	  
	restore

	preserve

		keep if useme==1
		local yearstring "All years"
		local cslcol=""

		quietly xtreg logoutlays logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
		keep if e(sample)
	   
		qui summ logoutlays if e(sample)
		local outcomemean=r(mean)
	  
		xtreg logoutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	  
		xtreg logoutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
		 
	restore
	 
	*Low variance spending next

		local outregtable "tableA12_capitals_table1"
		xtset fe_districtcensus fyear
		local clabel="District + Census Fixed Effects"

	preserve

		keep if useme==1
		local yearstring "All years"
		local cslcol=""
	 
		quietly xtreg logoutlays logalloutlays memberinpresparty memberinhouseparty chair rankingminority partyleader cmte_approp cmte_ways memberisrep closeelection presparty_close housmaj_close firstterm votemargin_pres_state presrep_distrepubtend houserep_distrepubtend yeardummy_*, fe vce(robust)
		keep if e(sample)

		qui summ logalloutlays if e(sample)
		local outcomemean=r(mean)
	 
		xtreg logalloutlays memberinpresparty memberinhouseparty yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
	 
		xtreg logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state memberinhouseparty  houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways memberisrep closeelection firstterm yeardummy_*, fe vce(robust)
			outreg2 using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	
			*outreg using "`outregtable'.out", ctitle("`clabel', `yearstring'`cslcol'") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append

	restore


*table 2, Part A, with State Capital Districts

	preserve

		xtset fe_districtcensusmemberpres fyear

		bysort fe_districtcensusmemberpres: egen minhouseisrep=min(houseisrep)
		bysort fe_districtcensusmemberpres: egen maxhouseisrep=max(houseisrep)
		count if minhouseisrep~=maxhouseisrep
			*These are people who experience a change
		drop if minhouseisrep==maxhouseisrep

		tab eyear houseisrep

	*generate time dummies
		drop yeardummy_*
		qui tab fyear, gen(yeardummy_)
		drop yeardummy_1

	*set sample
		qui xtreg  logoutlays logalloutlays presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm  yeardummy_*, fe vce(robust)
		drop if e(sample)~=1

	*Regressions	
		foreach dv of varlist logoutlays logalloutlays {

			if "`dv'"=="logoutlays" {
				local dvlabel="H. Var. Outlays"
			}
			else if "`dv'"=="logalloutlays" {
				local dvlabel="All Outlays"
			} 
			else {
				Crashing!
			}

			xtreg `dv' presparty_close votemargin_pres_state memberinhouseparty houserep_distrepubtend housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm  yeardummy_*, fe vce(robust)
			qui summ `dv' if e(sample)
			local outcomemean=r(mean)
		 
			if "`dv'"=="logoutlays" {
				 outreg2 using "tableA12_capitals_table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) replace		
				 *outreg using "tableA12_capitals_table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant") addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster replace
			}
			else {
				 outreg2 using "tableA12_capitals_table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append		
				 *outreg using "tableA12_capitals_table2.out", ctitle("`dvlabel', Holding Pres. Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
			}
	 
		}
	 
	 
	restore


*table 2, part B, with State Capital Districts

preserve

	xtset fe_districtcensusmemberhouse fyear

	bysort fe_districtcensusmemberhouse: egen minpresisrep=min(presisrep)
	bysort fe_districtcensusmemberhouse: egen maxpresisrep=max(presisrep)
	count if minpresisrep~=maxpresisrep
		*These are people who experience a change
	drop if minpresisrep==maxpresisrep

	tab eyear presisrep

*generate time dummies
	drop yeardummy_*
	qui tab fyear, gen(yeardummy_)
	drop yeardummy_1

*set sample
	qui xtreg logoutlays logalloutlays memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm, fe vce(robust)
	drop if e(sample)~=1

*regressions
	foreach dv of varlist logoutlays logalloutlays {

		if "`dv'"=="logoutlays" {
			local dvlabel="H. Var. Outlays"
		}
		else if "`dv'"=="logalloutlays" {
			local dvlabel="All Outlays"
		} 
		else {
			Crashing!
		}
 
		xtreg `dv' memberinpresparty presrep_distrepubtend presparty_close votemargin_pres_state housmaj_close partyleader chair rankingminority cmte_approp cmte_ways closeelection firstterm yeardummy_*, fe vce(robust)
	   
		qui summ `dv' if e(sample)
		local outcomemean=r(mean)
		
			outreg2 using "tableA12_capitals_table2.out", ctitle("`dvlabel', Holding House Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) append	 
			*outreg using "tableA12_capitals_table2.out", ctitle("`dvlabel', Holding House Party and Member Constant")  addstat("Mean of outcome in sample",`outcomemean')asterisk(se)bracket adec(3) bdec(3) tdec(3) 3aster append
 
	}

restore


******THE END: Script 3-2******




